from typing import Dict
from dataclasses import dataclass

from ....configs import ModelConfig


@dataclass
class CRNNImage2TextConfig(ModelConfig):
    name = "crnn_image2text"
    id2label: Dict[int, str] = None
    n_channels: int = 1
    img_height: int = 32
    map2seq_dim: int = 64
    rnn_dim: int = 256




from .f1 import F1, F1Config
from .accuracy import Accuracy, AccuracyConfig
from .metric import Metric
from .precision import Precision, PrecisionConfig
from .recall import Recall, RecallConfig
from .seqeval import Seqeval, SeqevalConfig



import importlib.util

__all__ = [
    "is_transformers_available",
    "is_datasets_available",
    "is_tokenizers_available",
    "is_soundfile_available",
    "is_librosa_available",
    "is_wandb_available",
    "is_gensim_available",
]


def is_transformers_available():
    return importlib.util.find_spec("transformers") is not None


def is_datasets_available():
    return importlib.util.find_spec("datasets") is not None


def is_tokenizers_available():
    return importlib.util.find_spec("tokenizers") is not None


def is_soundfile_available():
    return importlib.util.find_spec("soundfile") is not None


def is_librosa_available():
    return importlib.util.find_spec("librosa") is not None


def is_wandb_available():
    return importlib.util.find_spec("wandb") is not None


def is_gensim_available():
    return importlib.util.find_spec("gensim") is not None
